package org.lazywizard.console.commands;

import java.util.ArrayList;
import java.util.HashMap;
import java.util.List;
import java.util.Map;
import java.util.Objects;
import com.fs.starfarer.api.Global;
import com.fs.starfarer.api.campaign.CargoAPI;
import com.fs.starfarer.api.campaign.econ.MarketAPI;
import com.fs.starfarer.api.campaign.econ.SubmarketAPI;
import com.fs.starfarer.api.fleet.FleetMemberAPI;
import com.fs.starfarer.api.impl.campaign.ids.Submarkets;
import org.lazywizard.console.BaseCommand;
import org.lazywizard.console.CommonStrings;
import org.lazywizard.console.Console;

// TODO: ListStorage, lists all stored ships/items in all storages in the sector
public class ListStorage implements BaseCommand
{
    private static List<SubmarketAPI> getAllStorages()
    {
        List<SubmarketAPI> storages = new ArrayList<>();

        for (MarketAPI market : Global.getSector().getEconomy().getMarketsCopy())
        {
            if (market.hasSubmarket(Submarkets.SUBMARKET_STORAGE))
            {
                SubmarketAPI storage = market.getSubmarket(Submarkets.SUBMARKET_STORAGE);
                if (!storage.getCargo().isEmpty()
                        || !storage.getCargo().getMothballedShips().getMembersListCopy().isEmpty())
                {
                    storages.add(storage);
                }
            }
        }

        return storages;
    }

    @Override
    public CommandResult runCommand(String args, CommandContext context)
    {
        if (!context.isInCampaign())
        {
            Console.showMessage(CommonStrings.ERROR_CAMPAIGN_ONLY);
            return CommandResult.WRONG_CONTEXT;
        }

        final Map<String, List<CommodityReport>> items = new HashMap<>();
        final Map<String, Map.Entry<SubmarketAPI, Integer>> ships = new HashMap<>();
        final Map<String, Map.Entry<SubmarketAPI, Integer>> wings = new HashMap<>();
        final Map<String, Map.Entry<SubmarketAPI, Integer>> weapons = new HashMap<>();

        for (SubmarketAPI market : getAllStorages())
        {
            CargoAPI cargo = market.getCargo();
            Map<String, CommodityReport> reports = new HashMap<>();
            for (FleetMemberAPI member : cargo.getMothballedShips().getMembersListCopy())
            {
                String id = member.getHullId();
                CommodityReport report = reports.get(id);
                if (report == null)
                {
                    report = new CommodityReport(CommodityType.SHIP, id, 1);
                    reports.put(id, report);
                }
                else
                {
                    report.add(1);
                }
            }

            //for (
        }

        return CommandResult.SUCCESS;
    }

    private enum CommodityType
    {
        SHIP,
        WING,
        WEAPON,
        COMMODITY
    }

    private static class CommodityReport
    {
        private final CommodityType type;
        private final String id;
        private int total;

        private CommodityReport(CommodityType type, String id, int total)
        {
            this.type = type;
            this.id = id;
            this.total = total;
        }

        private void add(int toAdd)
        {
            total += toAdd;
        }

        private int getTotal()
        {
            return total;
        }

        @Override
        public boolean equals(Object obj)
        {
            if (obj == null)
            {
                return false;
            }

            if (getClass() != obj.getClass())
            {
                return false;
            }

            final CommodityReport other = (CommodityReport) obj;
            if (this.type != other.type)
            {
                return false;
            }

            return Objects.equals(this.id, other.id);
        }

        @Override
        public int hashCode()
        {
            int hash = 5;
            hash = 37 * hash + Objects.hashCode(this.type);
            hash = 37 * hash + Objects.hashCode(this.id);
            hash = 37 * hash + this.total;
            return hash;
        }
    }
}
